// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>

#include "algo.hh"
#include "colmap.hh"

ColMap::ColMap()
{
  init = false;
}

ColMap::~ColMap()
{
  for(int i=0; i<width; ++i) {
    delete[] ColMap::colmap[i];
  }
  delete[] ColMap::colmap;
}

int
ColMap::load(const char* filename)
{
  init = 1;
  //cout << "Init Colmap" << endl;

  ifstream in(filename);

  if (!in) {
    perror(filename);
    exit(EXIT_FAILURE);
  }

  width = 10;
  height = 10;

  in >> width;
  in >> height;

  // allocate the memory for the colmap
  ColMap::colmap = new int*[width];
  for(int i=0; i<width; ++i) {
    ColMap::colmap[i] = new int[height];
  }

  // load the colmap from file to memory
  int temp;

  for(int y=0; y < height; ++y) {
    for(int x=0; x < width; ++x) {

      // The level file is in RGB format, therefore the value need to 
      // be read in twice
      in >> temp;
      in >> temp;
      in >> temp;

      if (in.eof()) 
	cout << "in::eof" << endl;
      /*      if (temp != 0)
	      cout << "ColMap::not zero" << temp << endl;
	      else
	      cout << "ColMap::zero" << endl;
      */
      ColMap::colmap[x][y] = temp;
      //cout << colmap[x][y] << endl;
    }
  }
  //  cout << "Exit Colmap" << endl;
  //Pingu p(0,0);

  /*

  for(int y=0; y < height; ++y) {
    for(int x=0; x < width; ++x) {
      if (colmap[x][y] == 0)
	p.draw(x,y);
      else if (colmap[x][y] == 255)
	// cout << "ColMap Other Color" << endl;
	{}
      else
	cout << "Uff" << endl;
    }
  }
  */
  //  CL_Display::flip_display();
  //cout << "Totally Finished" << endl;

}

int
ColMap::getpixel(int x, int y)
{
  if (!init) {
    cout << "NOT INIT" << endl;
    exit(1);
  }
  //  return colmap[x][y];

  if (x >= 0 && x < width && y >= 0 && y < height) {
    
    for(int i=0; i < blocker.size(); ++i) {

      if (rect_col(x-16, y-32, x+16, y,
		   blocker[i].get_x()-16, blocker[i].get_y()-32, 
		   blocker[i].get_x()+16, blocker[i].get_y()))
	{
	  /*
      cout << x-16 << " "<< y-32<< " " << x+16<< " " << y << " "<< endl;
      cout << blocker[i].get_x()-16<< " " << blocker[i].get_y()-32 << " "
	   << blocker[i].get_x()+16<< " " << blocker[i].get_y() << endl << "----" << endl;
*/
	  return wall;
	}
    }

    return ColMap::colmap[x][y];
  } else {
    return wall;
  }
}

int
ColMap::set_blocker(int x, int y)
{
  //  for(int x1=x; x1 < x+32; ++x1)
  //    for(int y1=y; y1 < y+32; ++y1)
  //      colmap[x1][y1] = wall;
  blocker.push_back(Point::Point(x, y));
  return blocker.size() - 1;
}

void
ColMap::del_blocker(int blocker_id)
{
  //  blocker.erase();
}

/* EOF */
